@@ -198,6 +198,10 @@ extern "C" {
 #  define MRN_FOREIGN_KEY_USE_CONST_STRING
 #endif
 
+#if MYSQL_VERSION_ID >= 100203 && defined(MRN_MARIADB_P)
+#  define MRN_FOREIGN_KEY_USE_METHOD_ENUM
+#endif
+
 #if MYSQL_VERSION_ID < 50706 || defined(MRN_MARIADB_P)
 #  define MRN_HANDLER_IS_FATAL_ERROR_HAVE_FLAGS
 #endif
@@ -206,7 +210,8 @@ extern "C" {
 #  define MRN_HANDLER_HAVE_RESET_AUTO_INCREMENT
 #endif
 
-#if MYSQL_VERSION_ID >= 50709 && !defined(MRN_MARIADB_P)
+#if (!defined(MRN_MARIADB_P) && MYSQL_VERSION_ID >= 50709) ||   \
+  (defined(MRN_MARIADB_P) && MYSQL_VERSION_ID >= 100203)
 #  define MRN_ALTER_INPLACE_INFO_ALTER_STORED_COLUMN_TYPE \
   Alter_inplace_info::ALTER_STORED_COLUMN_TYPE
 #  define MRN_ALTER_INPLACE_INFO_ALTER_STORED_COLUMN_ORDER \
@@ -647,8 +652,7 @@ private:
   bool is_dry_write();
   bool is_enable_optimization();
   bool should_normalize(Field *field) const;
-  void check_count_skip(key_part_map start_key_part_map,
-                        key_part_map end_key_part_map, bool fulltext);
+  void check_count_skip(key_part_map target_key_part_map);
   bool is_grn_zero_column_value(grn_obj *column, grn_obj *value);
   bool is_primary_key_field(Field *field) const;
   void check_fast_order_limit(grn_table_sort_key **sort_keys, int *n_sort_keys,
